colour.characterisation.dataset.colour_checkers.spds Module — Colour 0.3.0 documentation

# colour.characterisation.dataset.colour_checkers.spds Module

## ColourCheckers Spectral Power Distributions

Defines ColourCheckers spectral power distributions.

Each ColourChecker data is in the form of a dict of `colour.colorimetry.spectrum.SpectralPowerDistribution` classes as follows:

    {'name': SpectralPowerDistribution, ..., 'name': SpectralPowerDistribution}

The following ColourCheckers data is available:

- `COLORCHECKER_N_OHTA_SPDS`: Measured by N. Ohta in 1997.
- `BABELCOLOR_AVERAGE_SPDS`: Average data derived from measurements of 30 ColourChecker charts.

See also

Colour Fitting IPython Notebook

References

[1] | N. Ohta, The Basis of Color Reproduction Engineering (Japanese), Corona-sha Co of Japan, published 1997. (Last accessed 24 February 2014)

[2] | http://www.rit-mcsl.org/UsefulData/MacbethColorChecker.xls (Last accessed 9 June 2014)

[3] | http://www.babelcolor.com/download/ColorChecker_RGB_and_spectra.xls (Last accessed 24 February 2014)

[4] | http://www.babelcolor.com/main_level/ColorChecker.htm

`colour.characterisation.dataset.colour_checkers.spds.` `COLORCHECKER_N_OHTA_SPDS` = {u'neutral 3.5 (1.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f0d0>, u'neutral 5 (.70 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f150>, u'white 9.5 (.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f190>, u'yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f1d0>, u'neutral 8 (.23 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f210>, u'magenta': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f250>, u'light skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f490>, u'blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f2d0>, u'purple': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f310>, u'orange': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f350>, u'blue sky': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f390>, u'dark skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f610>, u'blue flower': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f410>, u'neutral 6.5 (.44 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f450>, u'yellow green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f290>, u'bluish green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f4d0>, u'cyan': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f510>, u'moderate red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f550>, u'black 2 (1.5 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f590>, u'green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f5d0>, u'red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f3d0>, u'foliage': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f650>, u'purplish blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f690>, u'orange yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f6d0>}

  Measured by N. Ohta in 1997.

  COLORCHECKER_N_OHTA_SPDS : dict

`colour.characterisation.dataset.colour_checkers.spds.` `BABELCOLOR_AVERAGE_SPDS` = {u'neutral 3.5 (1.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f710>, u'neutral 5 (.70 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f750>, u'white 9.5 (.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f790>, u'yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f7d0>, u'neutral 8 (.23 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f810>, u'magenta': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f850>, u'light skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fa90>, u'blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f8d0>, u'purple': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f910>, u'orange': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f950>, u'blue sky': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f990>, u'dark skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fc10>, u'blue flower': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fa10>, u'neutral 6.5 (.44 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fa50>, u'yellow green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f890>, u'bluish green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fad0>, u'cyan': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fb10>, u'moderate red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fb50>, u'black 2 (1.5 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fb90>, u'green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fbd0>, u'red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f9d0>, u'foliage': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fc50>, u'purplish blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fc90>, u'orange yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fcd0>}

  Average data derived from measurements of 30 ColourChecker charts.

  BABELCOLOR_AVERAGE_SPDS : dict

`colour.characterisation.dataset.colour_checkers.spds.` `COLOURCHECKERS_SPDS` = CaseInsensitiveMapping({u'babel_average': {u'neutral 3.5 (1.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f710>, u'neutral 5 (.70 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f750>, u'white 9.5 (.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f790>, u'yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f7d0>, u'neutral 8 (.23 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f810>, u'magenta': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f850>, u'light skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fa90>, u'blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f8d0>, u'purple': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f910>, u'orange': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f950>, u'blue sky': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f990>, u'dark skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fc10>, u'blue flower': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fa10>, u'neutral 6.5 (.44 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fa50>, u'yellow green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f890>, u'bluish green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fad0>, u'cyan': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fb10>, u'moderate red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fb50>, u'black 2 (1.5 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fb90>, u'green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fbd0>, u'red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f9d0>, u'foliage': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fc50>, u'purplish blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fc90>, u'orange yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fcd0>}, u'ColorChecker N Ohta': {u'neutral 3.5 (1.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f0d0>, u'neutral 5 (.70 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f150>, u'white 9.5 (.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f190>, u'yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f1d0>, u'neutral 8 (.23 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f210>, u'magenta': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f250>, u'light skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f490>, u'blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f2d0>, u'purple': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f310>, u'orange': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f350>, u'blue sky': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f390>, u'dark skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f610>, u'blue flower': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f410>, u'neutral 6.5 (.44 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f450>, u'yellow green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f290>, u'bluish green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f4d0>, u'cyan': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f510>, u'moderate red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f550>, u'black 2 (1.5 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f590>, u'green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f5d0>, u'red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f3d0>, u'foliage': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f650>, u'purplish blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f690>, u'orange yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f6d0>}, u'BabelColor Average': {u'neutral 3.5 (1.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f710>, u'neutral 5 (.70 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f750>, u'white 9.5 (.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f790>, u'yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f7d0>, u'neutral 8 (.23 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f810>, u'magenta': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f850>, u'light skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fa90>, u'blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f8d0>, u'purple': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f910>, u'orange': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f950>, u'blue sky': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f990>, u'dark skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fc10>, u'blue flower': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fa10>, u'neutral 6.5 (.44 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fa50>, u'yellow green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f890>, u'bluish green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fad0>, u'cyan': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fb10>, u'moderate red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fb50>, u'black 2 (1.5 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fb90>, u'green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fbd0>, u'red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f9d0>, u'foliage': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fc50>, u'purplish blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fc90>, u'orange yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4fcd0>}, u'cc_ohta': {u'neutral 3.5 (1.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f0d0>, u'neutral 5 (.70 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f150>, u'white 9.5 (.05 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f190>, u'yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f1d0>, u'neutral 8 (.23 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f210>, u'magenta': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f250>, u'light skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f490>, u'blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f2d0>, u'purple': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f310>, u'orange': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f350>, u'blue sky': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f390>, u'dark skin': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f610>, u'blue flower': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f410>, u'neutral 6.5 (.44 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f450>, u'yellow green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f290>, u'bluish green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f4d0>, u'cyan': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f510>, u'moderate red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f550>, u'black 2 (1.5 D)': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f590>, u'green': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f5d0>, u'red': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f3d0>, u'foliage': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f650>, u'purplish blue': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f690>, u'orange yellow': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e4f6d0>}})

  Aggregated ColourCheckers spectral power distributions.

  COLOURCHECKERS : dict
    (‘BabelColor Average’, ‘ColorChecker N Ohta’)

  Aliases:

  - ‘babel_average’: ‘BabelColor Average’
  - ‘cc_ohta’: ‘ColorChecker N Ohta’